const assert = require('chai').assert;
const mapper = require('../index');

const config = {
    "name": {
        "dest": "nombre"
    },
    "price": {
        "dest": "precio",
        "transform": {
            "method": "percentage",
            "action": "addPercentage",
            "value": 10
        }
    },
    "wholesale": {
        "dest": "precioCompra",
        "transform": [
            {
                "method": "manipulate",
                "action": "stringToFloat"
            },
            {
                "method": "percentage",
                "action": "subPercentage",
                "value": 10
            }
        ]
    },
    "color": {
        "dest": "color"
    }
}

const data = {
    name: "Producto de test",
    price: 125,
    wholesale: "28",
    attributes: {
        color: 'red',
        size: 'L'
    }
}

describe('Tests for object-mapper-json: ', () => {
    describe('Pass a config object, data and returns mapped object: ', () => {
        it('Pass product_name and returns Object: ', () => {
            mapper.doMap(config, data, (err, data) => {
                assert.isObject(data, ' Returns an object');
            })
        })
        it('Pass product_name and object that contains producto key: ', () => {
            mapper.doMap(config, data, (err, data) => {
                assert.property(data, 'nombre');
            })
        })
        it('Pass product_name and object not returns product_name key: ', () => {
            mapper.doMap(config, data, (err, data) => {
                assert.notProperty(data, 'name');
            })
        })
        it('Pass product_name with value and returns object with producto = "Test product": ', () => {
            mapper.doMap(config, data, (err, data) => {
                assert.equal(data.nombre, 'Producto de test');
            })
        })
        it('Should calculate a discount: ', () => {
            mapper.doMap(config, data, (err, data) => {
                assert.equal(data.precio, 137.5);
            })
        })
    })
})